@@ -4,6 +4,8 @@ import os
 import telegram
 try:
     import RPi.GPIO as GPIO
+    import picamera
+    camera = picamera.PiCamera()
     GPIO.setwarnings(False)
     GPIO.setmode(GPIO.BOARD)
 except Exception as e:
@@ -149,7 +151,12 @@ class set:
                 update.message.reply_text("Bütün Kullanıcılar Silindi")
         def photo(update,context):
             if login(update,context):
-                update.message.reply_photo(chat_id=update.effective_chat.id, photo='https://telegram.org/img/t_logo.png')                
+                camera.start_preview()
+                time.sleep(5) # hang for preview for 5 seconds
+                camera.capture('raspauto.jpg')
+                camera.stop_preview()
+                time.sleep(5)
+                update.message.reply_photo(photo=open('raspauto.jpg','rb'))                
                 update.message.reply_text("Bütün Kullanıcılar Silindi")
 
         updater = Updater(self.tid, use_context=True)
